pub struct Node {
pub dot: Dot,
pub stage: Stage,
pub bits: BitVec<u64>,
pub payload: Option<Vec<u8>>,
pub context: Option<Vec<Dot>>,
pub predecessors: SmallVec<[usize; 4]>,
pub successors: SmallVec<[usize; 4]>,
}Expand description
Struct of a node from the causal dependency graph.
Fields
dot: DotMessage dot
stage: StageCurrent stage
bits: BitVec<u64>Bit string
payload: Option<Vec<u8>>Serialized message payload
context: Option<Vec<Dot>>Message context
predecessors: SmallVec<[usize; 4]>Indexes to the predecessors that are still in the graph
successors: SmallVec<[usize; 4]>Indexes to the successors that are still in the graph
Implementations