Module structs

Module structs 

Common structs of the middleware service.

Modules

message
Client message sent to be broadcast by the middleware.
message_type
Wrapper for the messages sent through the channels between threads.