ClientPeerMiddleware

Enum ClientPeerMiddleware 

pub enum ClientPeerMiddleware {
    Client {
        dot: Dot,
        msg: Vec<u8>,
        context: Vec<Dot>,
    },
    Peer {
        msg: Message,
    },
    Setup,
    Stable {
        dot: Dot,
    },
    End,
}
Enum for the messages that will be sent/received in the channels between the main middleware, stream reader and client

Variants



Client

Message sent by the Client to broadcast

Fields

dot: Dot
msg: Vec<u8>
context: Vec<Dot>


Peer

Message received from a peer

Fields



Setup

Indicates that the Middleware has finished the starting up



Stable

ACK by the Client that a message is causally stable

Fields

dot: Dot


End

Connection end