pub enum ClientPeerMiddleware {
Client {
dot: Dot,
msg: Vec<u8>,
context: Vec<Dot>,
},
Peer {
msg: Message,
},
Setup,
Stable {
dot: Dot,
},
End,
}Expand description
Enum for the messages that will be sent/received in the channels between the main middleware, stream reader and client
Variants
Client
Message sent by the Client to broadcast
Peer
Message received from a peer
Setup
Indicates that the Middleware has finished the starting up
Stable
ACK by the Client that a message is causally stable
End
Connection end